@@ -1,4 +1,4 @@
-// Copyright 2013-2024 Daniel Parker
+// Copyright 2013-2025 Daniel Parker
 // Distributed under the Boost license, Version 1.0.
 // (See accompanying file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
 
@@ -9,14 +9,12 @@
 
 #include <algorithm> // std::find, std::min, std::reverse
 #include <cmath>
-#include <exception>
-#include <istream> // std::basic_istream
+#include <cstddef>
 #include <iterator>
 #include <memory>
 #include <ostream>
 #include <stdexcept>
 #include <string>
-#include <vector>
 
 #include <jsoncons/config/compiler_support.hpp>
 
@@ -543,12 +541,12 @@ namespace std {
     template <typename CharT,typename Traits>
     struct hash<jsoncons::detail::basic_string_view<CharT, Traits>>
     {
-        size_t operator()(const jsoncons::detail::basic_string_view<CharT, Traits>& s) const noexcept
+        std::size_t operator()(const jsoncons::detail::basic_string_view<CharT, Traits>& s) const noexcept
         {
             const int p = 53;
             const int m = 1000000009;
-            size_t hash_value = 0;
-            size_t p_pow = 1;
+            std::size_t hash_value = 0;
+            std::size_t p_pow = 1;
             for (CharT c : s) {
                 hash_value = (hash_value + (c - 'a' + 1) * p_pow) % m;
                 p_pow = (p_pow * p) % m;
