@@ -165,11 +165,11 @@ namespace jsoncons {
             return more;
         }
 
-        template <typename Source>
-        bool byte_string_value(const Source& b, 
+        template <typename ByteStringLike>
+        bool byte_string_value(const ByteStringLike& b, 
                                semantic_tag tag=semantic_tag::none, 
                                const ser_context& context=ser_context(),
-                               typename std::enable_if<extension_traits::is_byte_sequence<Source>::value,int>::type = 0)
+                               typename std::enable_if<extension_traits::is_byte_sequence<ByteStringLike>::value,int>::type = 0)
         {
             std::error_code ec;
             bool more = visit_byte_string(byte_string_view(reinterpret_cast<const uint8_t*>(b.data()),b.size()), tag, context, ec);
@@ -180,11 +180,11 @@ namespace jsoncons {
             return more;
         }
 
-        template <typename Source>
-        bool byte_string_value(const Source& b, 
+        template <typename ByteStringLike>
+        bool byte_string_value(const ByteStringLike& b, 
                                uint64_t ext_tag, 
                                const ser_context& context=ser_context(),
-                               typename std::enable_if<extension_traits::is_byte_sequence<Source>::value,int>::type = 0)
+                               typename std::enable_if<extension_traits::is_byte_sequence<ByteStringLike>::value,int>::type = 0)
         {
             std::error_code ec;
             bool more = visit_byte_string(byte_string_view(reinterpret_cast<const uint8_t*>(b.data()),b.size()), ext_tag, context, ec);
