@@ -12,6 +12,8 @@
 #include <memory> // std::allocator
 
 #include <jsoncons/config/compiler_support.hpp>
+#include <jsoncons/config/jsoncons_config.hpp>
+#include <jsoncons/utility/extension_traits.hpp>
 
 namespace jsoncons {
 namespace utility {
