@@ -270,11 +270,12 @@ public:
     using char_type = CharT;
     using string_type = std::basic_string<CharT>;
 private:
-    char_type field_delimiter_;
-    char_type quote_char_;
-    char_type quote_escape_char_;
-    char_type subfield_delimiter_;
+    char_type field_delimiter_{','};
+    char_type quote_char_{'\"'};
+    char_type quote_escape_char_{'\"'};
+    char_type subfield_delimiter_{char_type{}};
 
+    bool flat_:1;
     bool enable_nan_to_num_:1;
     bool enable_inf_to_num_:1;
     bool enable_neginf_to_num_:1;
@@ -292,22 +293,21 @@ private:
     string_type inf_to_str_;
     string_type neginf_to_str_;
     string_type column_names_;
+    std::vector<std::pair<std::string,std::string>> column_mapping_; 
+    std::size_t max_nesting_depth_{1024};
 
 protected:
     basic_csv_options_common()
-      : field_delimiter_(','),
-        quote_char_('\"'),
-        quote_escape_char_('\"'),
-        subfield_delimiter_(char_type()),
-        enable_nan_to_num_(false),
-        enable_inf_to_num_(false),
-        enable_neginf_to_num_(false),
-        enable_nan_to_str_(false),
-        enable_inf_to_str_(false),
-        enable_neginf_to_str_(false),
-        enable_str_to_nan_(false),
-        enable_str_to_inf_(false),
-        enable_str_to_neginf_(false)
+      : flat_{true},                  
+        enable_nan_to_num_{false},    
+        enable_inf_to_num_{false},    
+        enable_neginf_to_num_{false}, 
+        enable_nan_to_str_{false},    
+        enable_inf_to_str_{false},    
+        enable_neginf_to_str_{false}, 
+        enable_str_to_nan_{false},    
+        enable_str_to_inf_{false},    
+        enable_str_to_neginf_{false}
     {
     }
 
@@ -318,6 +318,16 @@ protected:
     virtual ~basic_csv_options_common() = default;
 public:
 
+    bool flat() const 
+    {
+        return flat_;
+    }
+
+    std::size_t max_nesting_depth() const 
+    {
+        return max_nesting_depth_;
+    }
+
     char_type field_delimiter() const 
     {
         return field_delimiter_;
@@ -338,11 +348,16 @@ public:
         return quote_escape_char_;
     }
 
-    string_type column_names() const 
+    const string_type& column_names() const 
     {
         return column_names_;
     }
 
+    const std::vector<std::pair<std::string,std::string>>& column_mapping() const 
+    {
+        return column_mapping_;
+    }
+
     bool enable_nan_to_num() const
     {
         return enable_nan_to_num_;
@@ -467,8 +482,8 @@ private:
     bool unquoted_empty_value_is_null_:1;
     bool infer_types_:1;
     bool lossless_number_:1;
-    char_type comment_starter_;
-    csv_mapping_kind mapping_;
+    char_type comment_starter_{'\0'};
+    csv_mapping_kind mapping_{};
     std::size_t header_lines_{0};
     std::size_t max_lines_{(std::numeric_limits<std::size_t>::max)()};
     string_type column_types_;
@@ -484,9 +499,7 @@ public:
           trim_trailing_inside_quotes_(false),
           unquoted_empty_value_is_null_(false),
           infer_types_(true),
-          lossless_number_(false),
-          comment_starter_('\0'),
-          mapping_()
+          lossless_number_(false)
     {}
 
     basic_csv_decode_options(const basic_csv_decode_options& other) = default;
@@ -616,15 +629,12 @@ public:
     using typename super_type::char_type;
     using typename super_type::string_type;
 private:
-    quote_style_kind quote_style_;
-    float_chars_format float_format_;
-    int8_t precision_;
+    quote_style_kind quote_style_{quote_style_kind::minimal};
+    float_chars_format float_format_{float_chars_format::general};
+    int8_t precision_{0};
     string_type line_delimiter_;
 public:
     basic_csv_encode_options()
-      : quote_style_(quote_style_kind::minimal),
-        float_format_(float_chars_format::general),
-        precision_(0)
     {
         line_delimiter_.push_back('\n');
     }
@@ -682,11 +692,14 @@ public:
     using basic_csv_decode_options<CharT>::nan_to_num;
     using basic_csv_decode_options<CharT>::inf_to_num;
     using basic_csv_decode_options<CharT>::neginf_to_num;
+    using basic_csv_decode_options<CharT>::flat;
+    using basic_csv_decode_options<CharT>::max_nesting_depth;
     using basic_csv_decode_options<CharT>::field_delimiter;
     using basic_csv_decode_options<CharT>::subfield_delimiter;
     using basic_csv_decode_options<CharT>::quote_char;
     using basic_csv_decode_options<CharT>::quote_escape_char;
     using basic_csv_decode_options<CharT>::column_names;
+    using basic_csv_decode_options<CharT>::column_mapping;
     using basic_csv_decode_options<CharT>::header_lines; 
     using basic_csv_decode_options<CharT>::assume_header; 
     using basic_csv_decode_options<CharT>::ignore_empty_values; 
@@ -806,6 +819,12 @@ public:
         return *this;
     }
 
+    basic_csv_options& column_mapping(const std::vector<std::pair<std::string,std::string>>& value)
+    {
+        this->column_mapping_ = value;
+        return *this;
+    }
+
     basic_csv_options& column_types(const string_type& value)
     {
         this->column_types_ = value;
@@ -818,6 +837,18 @@ public:
         return *this;
     }
 
+    basic_csv_options& flat(bool value)
+    {
+        this->flat_ = value;
+        return *this;
+    }
+
+    basic_csv_options& max_nesting_depth(std::size_t value)
+    {
+        this->max_nesting_depth_ = value;
+        return *this;
+    }
+
     basic_csv_options& field_delimiter(char_type value)
     {
         this->field_delimiter_ = value;
