@@ -1,27 +1,33 @@
-// Copyright 2013-2024 Daniel Parker
+// Copyright 2013-2025 Daniel Parker
 // Distributed under the Boost license, Version 1.0.
 // (See accompanying file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
 
 // See https://github.com/danielaparker/jsoncons for latest version
 
-#ifndef JSONCONS_EXT_CSV_CSV_PARSER_HPP
-#define JSONCONS_EXT_CSV_CSV_PARSER_HPP
+#ifndef JSONCONS_CSV_CSV_PARSER_HPP
+#define JSONCONS_CSV_CSV_PARSER_HPP
 
 #include <cctype>
+#include <cstddef>
+#include <cstdint>
+#include <functional>
 #include <memory> // std::allocator
 #include <sstream>
-#include <stdexcept>
 #include <string>
 #include <system_error>
 #include <vector>
 
-#include <jsoncons/chunk_reader.hpp>
+#include <jsoncons/config/compiler_support.hpp>
+#include <jsoncons/config/jsoncons_config.hpp>
 #include <jsoncons/detail/parse_number.hpp>
-#include <jsoncons/json.hpp>
 #include <jsoncons/json_exception.hpp>
 #include <jsoncons/json_filter.hpp>
 #include <jsoncons/json_reader.hpp>
 #include <jsoncons/json_visitor.hpp>
+#include <jsoncons/ser_context.hpp>
+#include <jsoncons/staj_event.hpp>
+#include <jsoncons/tag_type.hpp>
+
 #include <jsoncons_ext/csv/csv_error.hpp>
 #include <jsoncons_ext/csv/csv_options.hpp>
 
@@ -37,41 +43,41 @@ enum class csv_mode
 
 enum class csv_parse_state 
 {
-    start,                           // 0
-    cr,                              // 1
-    column_labels,                   // 2 
-    expect_comment_or_record,        // 3
-    expect_record,                   // 4 
-    end_record,                      // 5
-    no_more_records,                 // 6 
-    comment,                         // 7
-    between_values,                  // 8
-    quoted_string,                   // 9
-    unquoted_string,                 // 10
-    before_unquoted_string,          // 11
-    escaped_value,                   // 12
-    minus,                           // 13
-    zero,                            // 14
-    integer,                         // 15
-    fraction,                        // 16
-    exp1,                            // 17                      
-    exp2,                            // 18
-    exp3,                            // 19 
-    accept,                          // 20
-    before_unquoted_field,           // 21
-    before_unquoted_field_tail,      // 22
-    before_unquoted_field_tail1,     // 23
-    before_last_unquoted_field,      // 24
-    before_last_unquoted_field_tail, // 25
-    before_unquoted_subfield,        // 26
-    before_unquoted_subfield_tail,   // 27 
-    before_quoted_subfield,          // 28
-    before_quoted_subfield_tail,     // 29
-    before_quoted_field,             // 30
-    before_quoted_field_tail,        // 31
-    before_last_quoted_field,        // 32
-    before_last_quoted_field_tail,   // 33
-    done                             // 34 
+    start,
+    cr, 
+    column_labels,
+    expect_comment_or_record,
+    expect_record,
+    end_record,
+    no_more_records,
+    comment,
+    between_values,
+    quoted_string,
+    unquoted_string,
+    before_unquoted_string,
+    escaped_value,
+    minus, 
+    zero,  
+    integer,
+    fraction,
+    exp1,
+    exp2,
+    exp3,
+    accept,
+    before_unquoted_field,
+    before_unquoted_field_tail, 
+    before_unquoted_field_tail1,
+    before_last_unquoted_field,
+    before_last_unquoted_field_tail,
+    before_unquoted_subfield,
+    before_unquoted_subfield_tail,
+    before_quoted_subfield,
+    before_quoted_subfield_tail,
+    before_quoted_field,
+    before_quoted_field_tail,
+    before_last_quoted_field,
+    before_last_quoted_field_tail,
+    done
 };
 
 enum class cached_state
@@ -226,11 +232,11 @@ namespace detail {
         using parse_event_vector_allocator_type = typename std::allocator_traits<temp_allocator_type>:: template rebind_alloc<parse_event_vector_type>;
     private:
         TempAllocator alloc_;
-        std::size_t name_index_{0};
-        int level_{0};
+        std::size_t name_index_;
+        int level_;
         cached_state state_;
-        std::size_t column_index_{0};
-        std::size_t row_index_{0};
+        std::size_t column_index_;
+        std::size_t row_index_;
 
         std::vector<string_type, string_allocator_type> column_names_;
         std::vector<parse_event_vector_type,parse_event_vector_allocator_type> cached_events_;
@@ -238,13 +244,15 @@ namespace detail {
 
         m_columns_filter(const TempAllocator& alloc)
             : alloc_(alloc),
+              name_index_(0), 
+              level_(0), 
               state_(cached_state::begin_object), 
+              column_index_(0), 
+              row_index_(0),
               column_names_(alloc),
               cached_events_(alloc)
         {
         }
-        
-        ~m_columns_filter() = default;
 
         void reset()
         {
@@ -493,12 +501,11 @@ namespace detail {
 } // namespace detail
 
 template <typename CharT,typename TempAllocator =std::allocator<char>>
-class basic_csv_parser : public ser_context, public virtual basic_parser_input<CharT>
+class basic_csv_parser : public ser_context
 {
 public:
     using string_view_type = jsoncons::basic_string_view<CharT>;
     using char_type = CharT;
-    using chunk_reader_type = std::function<bool(basic_parser_input<CharT>& input, std::error_code& ec)>;
 private:
     struct string_maps_to_double
     {
@@ -525,19 +532,19 @@ private:
     csv_parse_state state_;
     basic_json_visitor<CharT>* visitor_;
     std::function<bool(csv_errc,const ser_context&)> err_handler_;
-    std::size_t column_{1};
-    std::size_t line_{1};
-    int depth_{default_depth};
+    std::size_t column_;
+    std::size_t line_;
+    int depth_;
     const basic_csv_decode_options<CharT> options_;
-    std::size_t column_index_{0};
-    std::size_t level_{0};
-    std::size_t offset_{0};
+    std::size_t column_index_;
+    std::size_t level_;
+    std::size_t offset_;
     jsoncons::detail::chars_to to_double_; 
     const CharT* begin_input_;
     const CharT* input_end_;
     const CharT* input_ptr_;
-    bool more_{true};
-    std::size_t header_line_{1};
+    bool more_;
+    std::size_t header_line_;
 
     detail::m_columns_filter<CharT,TempAllocator> m_columns_filter_;
     std::vector<csv_mode,csv_mode_allocator_type> stack_;
@@ -548,12 +555,9 @@ private:
     string_type buffer_;
     std::vector<std::pair<std::basic_string<char_type>,double>> string_double_map_;
 
-    chunk_reader_adaptor<char_type> chk_rdr_;
-    chunk_reader<char_type>* chunk_rdr_;
-
 public:
     basic_csv_parser(const TempAllocator& alloc = TempAllocator())
-       : basic_csv_parser(&chk_rdr_,basic_csv_decode_options<CharT>(), 
+       : basic_csv_parser(basic_csv_decode_options<CharT>(), 
                           default_csv_parsing(),
                           alloc)
     {
@@ -561,45 +565,46 @@ public:
 
     basic_csv_parser(const basic_csv_decode_options<CharT>& options,
                      const TempAllocator& alloc = TempAllocator())
-        : basic_csv_parser(&chk_rdr_, options, default_csv_parsing(), alloc)
-    {
-    }
-
-    basic_csv_parser(const basic_csv_decode_options<CharT>& options,
-        std::function<bool(csv_errc,const ser_context&)> err_handler,
-        const TempAllocator& alloc = TempAllocator())
-        : basic_csv_parser(&chk_rdr_, options, err_handler, alloc)
+        : basic_csv_parser(options, 
+                           default_csv_parsing(),
+                           alloc)
     {
     }
 
     basic_csv_parser(std::function<bool(csv_errc,const ser_context&)> err_handler,
                      const TempAllocator& alloc = TempAllocator())
-        : basic_csv_parser(&chk_rdr_, basic_csv_decode_options<CharT>(), 
+        : basic_csv_parser(basic_csv_decode_options<CharT>(), 
                            err_handler,
                            alloc)
     {
     }
 
-    basic_csv_parser(chunk_reader<CharT>* chunk_rdr,
-        const basic_csv_decode_options<CharT>& options,
-        std::function<bool(csv_errc,const ser_context&)> err_handler,
-        const TempAllocator& alloc = TempAllocator())
+    basic_csv_parser(const basic_csv_decode_options<CharT>& options,
+                     std::function<bool(csv_errc,const ser_context&)> err_handler,
+                     const TempAllocator& alloc = TempAllocator())
        : alloc_(alloc),
          state_(csv_parse_state::start),
          visitor_(nullptr),
          err_handler_(err_handler),
+         column_(1),
+         line_(1),
+         depth_(default_depth),
          options_(options),
+         column_index_(0),
+         level_(0),
+         offset_(0),
          begin_input_(nullptr),
          input_end_(nullptr),
          input_ptr_(nullptr),
+         more_(true),
+         header_line_(1),
          m_columns_filter_(alloc),
          stack_(alloc),
          column_names_(alloc),
          column_types_(alloc),
          column_defaults_(alloc),
          state_stack_(alloc),
-         buffer_(alloc),
-         chunk_rdr_(chunk_rdr)
+         buffer_(alloc)
     {
         if (options_.enable_str_to_nan())
         {
@@ -617,7 +622,9 @@ public:
         initialize();
     }
 
-    ~basic_csv_parser() = default;
+    ~basic_csv_parser() noexcept
+    {
+    }
 
     bool done() const
     {
@@ -699,143 +706,129 @@ public:
 
         const CharT* local_input_end = input_end_;
 
-        while (more_)
+        if (input_ptr_ == local_input_end && more_)
         {
-            if (input_ptr_ == local_input_end)
+            switch (state_)
             {
-                if (!chunk_rdr_->read_chunk(*this, ec))
-                {
-                    if (ec) 
+                case csv_parse_state::start:
+                    ec = csv_errc::source_error;
+                    more_ = false;
+                    return;
+                case csv_parse_state::before_unquoted_field:
+                case csv_parse_state::before_last_unquoted_field:
+                    end_unquoted_string_value(ec);
+                    state_ = csv_parse_state::before_last_unquoted_field_tail;
+                    break;
+                case csv_parse_state::before_last_unquoted_field_tail:
+                    if (stack_.back() == csv_mode::subfields)
                     {
+                        stack_.pop_back();
+                        more_ = visitor_->end_array(*this, ec);
+                    }
+                    ++column_index_;
+                    state_ = csv_parse_state::end_record;
+                    break;
+                case csv_parse_state::before_unquoted_string: 
+                    buffer_.clear();
+                    JSONCONS_FALLTHROUGH;
+                case csv_parse_state::unquoted_string: 
+                    if (options_.trim_leading() || options_.trim_trailing())
+                    {
+                        trim_string_buffer(options_.trim_leading(),options_.trim_trailing());
+                    }
+                    if (options_.ignore_empty_values() && buffer_.empty())
+                    {
+                        state_ = csv_parse_state::end_record;
+                    }
+                    else
+                    {
+                        before_value(ec);
+                        state_ = csv_parse_state::before_unquoted_field;
+                    }
+                    break;
+                case csv_parse_state::before_last_quoted_field:
+                    end_quoted_string_value(ec);
+                    ++column_index_;
+                    state_ = csv_parse_state::end_record;
+                    break;
+                case csv_parse_state::escaped_value:
+                    if (options_.quote_escape_char() == options_.quote_char())
+                    {
+                        if (!(options_.ignore_empty_values() && buffer_.empty()))
+                        {
+                            before_value(ec);
+                            ++column_;
+                            state_ = csv_parse_state::before_last_quoted_field;
+                        }
+                        else
+                        {
+                            state_ = csv_parse_state::end_record;
+                        }
+                    }
+                    else
+                    {
+                        ec = csv_errc::invalid_escaped_char;
                         more_ = false;
                         return;
                     }
-
-                    while (more_)
+                    break;
+                case csv_parse_state::end_record:
+                    if (column_index_ > 0)
                     {
-                        switch (state_)
+                        after_record(ec);
+                    }
+                    state_ = csv_parse_state::no_more_records;
+                    break;
+                case csv_parse_state::no_more_records: 
+                    switch (stack_.back()) 
+                    {
+                        case csv_mode::header:
+                            stack_.pop_back();
+                            break;
+                        case csv_mode::data:
+                            stack_.pop_back();
+                            break;
+                        default:
+                            break;
+                    }
+                    more_ = visitor_->end_array(*this, ec);
+                    if (options_.mapping_kind() == csv_mapping_kind::m_columns)
+                    {
+                        if (!m_columns_filter_.done())
                         {
-                            case csv_parse_state::start:
-                                ec = csv_errc::source_error;
-                                more_ = false;
-                                return;
-                            case csv_parse_state::accept:
-                                if (!(stack_.size() == 1 && stack_.back() == csv_mode::initial))
-                                {
-                                    err_handler_(csv_errc::unexpected_eof, *this);
-                                    ec = csv_errc::unexpected_eof;
-                                    more_ = false;
-                                    return;
-                                }
-                                stack_.pop_back();
-                                visitor_->flush();
-                                state_ = csv_parse_state::done;
-                                more_ = false;
-                                return;
-                            case csv_parse_state::before_unquoted_field:
-                            case csv_parse_state::before_last_unquoted_field:
-                                end_unquoted_string_value(ec);
-                                state_ = csv_parse_state::before_last_unquoted_field_tail;
-                                break;
-                            case csv_parse_state::before_last_unquoted_field_tail:
-                                if (stack_.back() == csv_mode::subfields)
-                                {
-                                    stack_.pop_back();
-                                    more_ = visitor_->end_array(*this, ec);
-                                }
-                                ++column_index_;
-                                state_ = csv_parse_state::end_record;
-                                break;
-                            case csv_parse_state::before_unquoted_string: 
-                                buffer_.clear();
-                                JSONCONS_FALLTHROUGH;
-                            case csv_parse_state::unquoted_string: 
-                                if (options_.trim_leading() || options_.trim_trailing())
-                                {
-                                    trim_string_buffer(options_.trim_leading(),options_.trim_trailing());
-                                }
-                                if (options_.ignore_empty_values() && buffer_.empty())
-                                {
-                                    state_ = csv_parse_state::end_record;
-                                }
-                                else
-                                {
-                                    before_value(ec);
-                                    state_ = csv_parse_state::before_unquoted_field;
-                                }
-                                break;
-                            case csv_parse_state::before_last_quoted_field:
-                                end_quoted_string_value(ec);
-                                ++column_index_;
-                                state_ = csv_parse_state::end_record;
-                                break;
-                            case csv_parse_state::escaped_value:
-                                if (options_.quote_escape_char() == options_.quote_char())
-                                {
-                                    if (!(options_.ignore_empty_values() && buffer_.empty()))
-                                    {
-                                        before_value(ec);
-                                        ++column_;
-                                        state_ = csv_parse_state::before_last_quoted_field;
-                                    }
-                                    else
-                                    {
-                                        state_ = csv_parse_state::end_record;
-                                    }
-                                }
-                                else
-                                {
-                                    ec = csv_errc::invalid_escaped_char;
-                                    more_ = false;
-                                    return;
-                                }
-                                break;
-                            case csv_parse_state::end_record:
-                                if (column_index_ > 0)
-                                {
-                                    after_record(ec);
-                                }
-                                state_ = csv_parse_state::no_more_records;
-                                break;
-                            case csv_parse_state::no_more_records: 
-                                switch (stack_.back()) 
-                                {
-                                    case csv_mode::header:
-                                        stack_.pop_back();
-                                        break;
-                                    case csv_mode::data:
-                                        stack_.pop_back();
-                                        break;
-                                    default:
-                                        break;
-                                }
-                                more_ = visitor_->end_array(*this, ec);
-                                if (options_.mapping_kind() == csv_mapping_kind::m_columns)
-                                {
-                                    if (!m_columns_filter_.done())
-                                    {
-                                        more_ = m_columns_filter_.replay_parse_events(visitor);
-                                    }
-                                    else
-                                    {
-                                        state_ = csv_parse_state::accept;
-                                    }
-                                }
-                                else
-                                {
-                                    state_ = csv_parse_state::accept;
-                                }
-                                break;
-                            default:
-                                state_ = csv_parse_state::end_record;
-                                break;
+                            more_ = m_columns_filter_.replay_parse_events(visitor);
+                        }
+                        else
+                        {
+                            state_ = csv_parse_state::accept;
                         }
                     }
+                    else
+                    {
+                        state_ = csv_parse_state::accept;
+                    }
+                    break;
+                case csv_parse_state::accept:
+                    if (!(stack_.size() == 1 && stack_.back() == csv_mode::initial))
+                    {
+                        err_handler_(csv_errc::unexpected_eof, *this);
+                        ec = csv_errc::unexpected_eof;
+                        more_ = false;
+                        return;
+                    }
+                    stack_.pop_back();
+                    visitor_->flush();
+                    state_ = csv_parse_state::done;
+                    more_ = false;
+                    return;
+                default:
+                    state_ = csv_parse_state::end_record;
                     break;
-                }
-                local_input_end = input_end_;
             }
+        }
 
+        for (; (input_ptr_ < local_input_end) && more_;)
+        {
             CharT curr_char = *input_ptr_;
 
             switch (state_) 
@@ -1313,28 +1306,17 @@ public:
         return state_;
     }
 
-#if !defined(JSONCONS_NO_DEPRECATED)
-    JSONCONS_DEPRECATED_MSG("Instead, use set_buffer once or provide a chunk reader")
     void update(const string_view_type sv)
     {
         update(sv.data(),sv.length());
     }
 
-    JSONCONS_DEPRECATED_MSG("Instead, use set_buffer once or provide a chunk reader")
     void update(const CharT* data, std::size_t length)
     {
         begin_input_ = data;
         input_end_ = data + length;
         input_ptr_ = begin_input_;
     }
-#endif
-
-    void set_buffer(const CharT* data, std::size_t length) final
-    {
-        begin_input_ = data;
-        input_end_ = data + length;
-        input_ptr_ = begin_input_;
-    }
 
     std::size_t line() const override
     {
@@ -1658,7 +1640,7 @@ private:
         auto it = std::find_if(string_double_map_.begin(), string_double_map_.end(), string_maps_to_double{ buffer_ });
         if (it != string_double_map_.end())
         {
-            more_ = visitor_->double_value(it->second, semantic_tag::none, *this, ec);
+            more_ = visitor_->double_value((*it).second, semantic_tag::none, *this, ec);
         }
         else if (column_index_ < column_types_.size() + offset_)
         {
@@ -1689,7 +1671,7 @@ private:
                 case csv_column_type::integer_t:
                     {
                         std::basic_istringstream<CharT,std::char_traits<CharT>,char_allocator_type> iss{buffer_};
-                        int64_t val{};
+                        int64_t val;
                         iss >> val;
                         if (!iss.fail())
                         {
@@ -1700,7 +1682,7 @@ private:
                             if (column_index_ - offset_ < column_defaults_.size() && column_defaults_[column_index_ - offset_].length() > 0)
                             {
                                 basic_json_parser<CharT,temp_allocator_type> parser(alloc_);
-                                parser.set_buffer(column_defaults_[column_index_ - offset_].data(),column_defaults_[column_index_ - offset_].length());
+                                parser.update(column_defaults_[column_index_ - offset_].data(),column_defaults_[column_index_ - offset_].length());
                                 parser.parse_some(*visitor_);
                                 parser.finish_parse(*visitor_);
                             }
@@ -1720,7 +1702,7 @@ private:
                         else
                         {
                             std::basic_istringstream<CharT, std::char_traits<CharT>, char_allocator_type> iss{ buffer_ };
-                            double val{};
+                            double val;
                             iss >> val;
                             if (!iss.fail())
                             {
@@ -1731,7 +1713,7 @@ private:
                                 if (column_index_ - offset_ < column_defaults_.size() && column_defaults_[column_index_ - offset_].length() > 0)
                                 {
                                     basic_json_parser<CharT,temp_allocator_type> parser(alloc_);
-                                    parser.set_buffer(column_defaults_[column_index_ - offset_].data(),column_defaults_[column_index_ - offset_].length());
+                                    parser.update(column_defaults_[column_index_ - offset_].data(),column_defaults_[column_index_ - offset_].length());
                                     parser.parse_some(*visitor_);
                                     parser.finish_parse(*visitor_);
                                 }
@@ -1766,7 +1748,7 @@ private:
                             if (column_index_ - offset_ < column_defaults_.size() && column_defaults_[column_index_ - offset_].length() > 0)
                             {
                                 basic_json_parser<CharT,temp_allocator_type> parser(alloc_);
-                                parser.set_buffer(column_defaults_[column_index_ - offset_].data(),column_defaults_[column_index_ - offset_].length());
+                                parser.update(column_defaults_[column_index_ - offset_].data(),column_defaults_[column_index_ - offset_].length());
                                 parser.parse_some(*visitor_);
                                 parser.finish_parse(*visitor_);
                             }
@@ -1787,7 +1769,7 @@ private:
                         if (column_index_ < column_defaults_.size() + offset_ && column_defaults_[column_index_ - offset_].length() > 0)
                         {
                             basic_json_parser<CharT,temp_allocator_type> parser(alloc_);
-                            parser.set_buffer(column_defaults_[column_index_ - offset_].data(),column_defaults_[column_index_ - offset_].length());
+                            parser.update(column_defaults_[column_index_ - offset_].data(),column_defaults_[column_index_ - offset_].length());
                             parser.parse_some(*visitor_);
                             parser.finish_parse(*visitor_);
                         }
@@ -2119,8 +2101,7 @@ private:
 using csv_parser = basic_csv_parser<char>;
 using wcsv_parser = basic_csv_parser<wchar_t>;
 
-} // namespace jsonpath
-} // namespace jsoncons
+}}
 
-#endif // JSONCONS_EXT_CSV_CSV_PARSER_HPP
+#endif
 
