@@ -1,4 +1,4 @@
-/// Copyright 2013-2024 Daniel Parker
+/// Copyright 2013-2025 Daniel Parker
 // Distributed under the Boost license, Version 1.0.
 // (See accompanying file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
 
@@ -7,7 +7,15 @@
 #ifndef JSONCONS_EXT_CSV_DECODE_CSV_HPP
 #define JSONCONS_EXT_CSV_DECODE_CSV_HPP
 
+#include <type_traits>
+
 #include <jsoncons/allocator_set.hpp>
+#include <jsoncons/config/compiler_support.hpp>
+#include <jsoncons/basic_json.hpp>
+#include <jsoncons/decode_traits.hpp>
+#include <jsoncons/json_exception.hpp>
+#include <jsoncons/source.hpp>
+
 #include <jsoncons_ext/csv/csv_cursor.hpp>
 #include <jsoncons_ext/csv/csv_encoder.hpp>
 #include <jsoncons_ext/csv/csv_options.hpp>
