@@ -1,4 +1,4 @@
-﻿// Copyright 2013-2024 Daniel Parker
+﻿// Copyright 2013-2025 Daniel Parker
 // Distributed under the Boost license, Version 1.0.
 // (See accompanying file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
 
@@ -8,14 +8,15 @@
 #define JSONCONS_EXT_JSONPATH_PATH_NODE_HPP
 
 #include <algorithm> // std::reverse
+#include <cstddef>
 #include <functional>
+#include <memory>
 #include <string>
 #include <vector>
 
 #include <jsoncons/config/jsoncons_config.hpp>
 #include <jsoncons/detail/write_number.hpp>
 #include <jsoncons/json_type.hpp>
-#include <jsoncons_ext/jsonpath/jsonpath_error.hpp>
 #include <jsoncons_ext/jsonpath/jsonpath_utilities.hpp>
 
 namespace jsoncons { 
@@ -259,7 +260,7 @@ namespace jsonpath {
                 {
                     return nullptr;
                 }
-                current = std::addressof(it->value());
+                current = std::addressof((*it).value());
             }
         }
         return current;
