@@ -1,10 +1,10 @@
-// Copyright 2013-2024 Daniel Parker
+// Copyright 2013-2025 Daniel Parker
 // Distributed under Boost license
 
-#include <catch/catch.hpp>
 #include <jsoncons/detail/span.hpp>
 #include <iostream>
 #include <vector>
+#include <catch/catch.hpp>
 
 TEST_CASE("jsoncons::detail::span constructor tests")
 {
@@ -23,7 +23,7 @@ TEST_CASE("jsoncons::detail::span constructor tests")
     SECTION("jsoncons::detail::span(C& c)")
     {
         using C = std::vector<uint8_t>;
-        C c = {1,2,3,4};
+        C c = {{1,2,3,4}};
 
         jsoncons::detail::span<const uint8_t> s(c);
         CHECK(s.size() == c.size());
@@ -39,7 +39,7 @@ TEST_CASE("jsoncons::detail::span constructor tests")
     }
     SECTION("jsoncons::detail::span(std::array)")
     {
-        std::array<double,4> c = {1,2,3,4};
+        std::array<double,4> c = {{1,2,3,4}};
 
         jsoncons::detail::span<double> s(c);
         CHECK(s.size() == 4);
