@@ -1,18 +1,21 @@
-// Copyright 2013-2024 Daniel Parker
+// Copyright 2013-2025 Daniel Parker
 // Distributed under Boost license
 
 #if defined(_MSC_VER)
 #include "windows.h" // test no inadvertant macro expansions
 #endif
-#include <jsoncons/json.hpp>
+
 #include <jsoncons/json_encoder.hpp>
 #include <jsoncons_ext/csv/csv_cursor.hpp>
 #include <jsoncons_ext/csv/csv.hpp>
-#include <catch/catch.hpp>
+
+#include <jsoncons/json.hpp>
+
 #include <sstream>
 #include <vector>
 #include <utility>
 #include <ctime>
+#include <catch/catch.hpp>
 
 using namespace jsoncons;
 
@@ -883,7 +886,7 @@ TEST_CASE("test_csv_parser_reinitialization")
     std::string input = "h1,h2\n"
                         "3,4\n"
                         "5,6\n";
-    parser.set_buffer(input.data(), input.size());
+    parser.update(input.data(), input.size());
     int count = 0;
     while (!parser.stopped() && count < 20)
     {
@@ -900,7 +903,7 @@ TEST_CASE("test_csv_parser_reinitialization")
     parser.reinitialize();
     input = "h7,h8\n"
             "9,10\n";
-    parser.set_buffer(input.data(), input.size());
+    parser.update(input.data(), input.size());
     count = 0;
     while (!parser.stopped() && count < 20)
     {
